unit LedGroup;

interface

uses                             
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  stdctrls, DigitLed;

{*******************************************************************************
*   LedGroup - a Component to display text with 7 & 11 segments leds.          *
*              Groups DigitLed components.                                     *
*   ~~~~~~~~                                                                   *
*   2.02 - the version I found in the internet                                 *
*   2.03 - converted to LAZARUS  by BREAKOUTBOX  2010-08-05                    *
*                                                                              *
*******************************************************************************}
const LedGroupversion = '2.03';

type
  TDigitLedGroup = class(TCustomGroupBox)
  private
    { Private declarations }
    FMaxDigits : byte;      //Number of digits
    Led        : TDigitLed;
    FCaption   : String;
    FCommaPos  : Byte;
    FOnColor   : TColor;
    FOffColor  : TColor;
    FMargin    : Byte;
    FLedStyle  : TLedStyle;
    FVersion   : String;
    procedure CreateDigits;
    procedure SetMaxDigits( Num:Byte);
    procedure SetCaption( aCaption:String);
    procedure SetCommaPos( Position:Byte);
    procedure SetOnColor( aColor:TColor);
    procedure SetOffColor( aColor:TColor);
    Procedure SetMargin( value:Byte);
    procedure SetStyle( NewStyle:TLedStyle);
    procedure SetVersion( ver:String);
  protected
    { Protected declarations }
    procedure Paint; {$IFNDEF FPC}override;{$ENDIF}
  public
    { Public declarations }
    constructor Create( AOwner: TComponent); override;
  published
    { Published declarations }
    property MaxDigits : Byte Read FMaxDigits Write SetMaxDigits Default 5;
    property Caption : String Read FCaption Write SetCaption;
    property LedStyle : TLedStyle Read FLedStyle Write SetStyle Default lsElevenBars;
    property CommaPos : Byte Read FCommaPos Write SetCommaPos Default 0;
    property OnColor : TColor Read FOnColor Write SetOnColor;
    property OffColor : TColor Read FOffColor Write SetOffColor;
    property Margin : Byte Read FMargin Write SetMargin Default 0;
    property Color;
    property ShowHint;
    property Version : String Read FVersion Write SetVersion;
  end;

procedure Register;


implementation

{$R *.dcr}

constructor TDigitLedGroup.Create( AOwner: TComponent);
begin
  inherited;
  FVersion:= LedGroupversion;
  Height:= 65;
  Width:= 185;
  FCaption:= '';
  FMargin:= 0;
  MaxDigits:= 5;
  FCommaPos:= 0;
  if ComponentState=[csDesigning] then
    begin
      MaxDigits:= 7;
      FCaption:= 'MoonRed';
      FOnColor:= clGreen;
      FOffColor:= clBtnFace;
    end;
  Color:= FOffColor;
  FLedStyle:= lsElevenBars;
  CreateDigits;
end;

procedure TDigitLedGroup.SetVersion( ver:String);
begin
  FVersion:= LedGroupversion;
end;

procedure TDigitLedGroup.SetMaxDigits( Num:Byte);
begin
  FMaxDigits:=Num;
  CreateDigits;
  paint;
end;

procedure TDigitLedGroup.CreateDigits;
var f:byte;
   aux: TComponent;
begin
for f:=1 to FMaxDigits do
  begin
  aux:=FindComponent('Led'+IntToStr(f));
  if (aux=nil) then  // if the led number does not exists
     begin  //creates the led
     Led:=TDigitled.Create(self);
     Led.Name:='Led'+IntToStr(f);
     led.top:=Margin;
     led.width:=Round((Width-Margin) / FMaxDigits);
     led.left:=(f-1)*(Round((Width-Margin-Margin) / FMaxDigits))+Margin;
     led.height:=height-(Margin+Margin);
     InsertControl(Led);
     end;
  end;

end;

procedure TDigitLedGroup.Paint;
var
  f:byte;
begin
if ComponentCount>0 then
   begin
   for f:=0 to ComponentCount-1 do
    begin
    TWinControl(Components[f]).width:=round((Width-Margin) / FMaxDigits);
    TWinControl(Components[f]).left:=(f)*(Round((Width-Margin-Margin) / FMaxDigits))+Margin;
    TWinControl(Components[f]).top:=Margin;
    TWinControl(Components[f]).height:=height-(Margin+Margin);
    end;
   end;
end;


procedure TDigitLedGroup.SetCaption( aCaption:String);
var
  f:byte;
begin
 if (Length( aCaption) > 0) then
   begin
   FCaption:= copy( aCaption + '                    ', 1, maxDigits);
   if Length( aCaption) > ComponentCount
     then CreateDigits;
   for f:= 0 to MaxDigits{length(Caption)}-1 do
     begin
       TDigitLed( components[f]).character:= FCaption[f + 1];
       if f+1= CommaPos
         then TDigitLed(components[f]).Segments:= TDigitLed(components[f]).segments+[bPoint]
         else TDigitLed(components[f]).Segments:= TDigitLed(components[f]).segments-[bPoint];
     end;
  end;
end;

procedure TDigitLedGroup.SetCommaPos( Position:Byte);
var
  f:byte;
begin
if (Position<=MaxDigits) and (Position>0) then
   begin
   FCommaPos:=Position;
   for f:=0 to ComponentCount-1 do
    begin
    if (f=Position-1) then //is the correct position
       begin
       TDigitLed(Components[f]).Segments:=TDigitLed(Components[f]).Segments+[bpoint]
       end
    else
       begin
       TDigitLed(Components[f]).Segments:=TDigitLed(Components[f]).Segments-[bpoint]
       end
    end // for
   end
else
   begin
   for f:=0 to ComponentCount-1 do
    begin
    TDigitLed(Components[f]).Segments:=TDigitLed(Components[f]).Segments-[bpoint]
    end // for
   end;
end;

procedure TDigitLedGroup.SetOnColor( aColor:TColor);
var
  f:byte;
begin
  FOnColor:= aColor;
  for f:= 0 to ComponentCount-1 do
    TDigitLed(Components[f]).OnColor:= aColor;
end;

procedure TDigitLedGroup.SetOffColor( aColor:TColor);
var
  f:byte;
begin
  FOffColor:= aColor;
  for f:= 0 to ComponentCount-1 do
    TDigitLed(Components[f]).OffColor:= aColor;
end;

procedure TDigitLedGroup.SetMargin( Value:Byte);
begin
  FMargin:= Value;
  Paint;
end;

procedure TDigitLedGroup.SetStyle( NewStyle:TLedStyle);
var
  f:Byte;
begin
  FLedStyle:= NewStyle;
  for f:= 0 to ComponentCount-1 do
    TDigitLed(Components[f]).LedStyle:= FLedStyle;
  SetCaption( FCaption);
end;


procedure Register;
begin
  RegisterComponents( 'LEDcomponents', [TDigitLedGroup]);
end;


end.
